@@ -6,12 +6,12 @@ use warnings;
 use Log::ger;
 
 use Fcntl;
-use File::MoreUtil qw(file_exists l_abs_path);
+use File::Util::Test qw(file_exists l_abs_path);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-08-07'; # DATE
+our $DATE = '2023-11-21'; # DATE
 our $DIST = 'File-Trash-FreeDesktop'; # DIST
-our $VERSION = '0.205'; # VERSION
+our $VERSION = '0.206'; # VERSION
 
 sub new {
     require File::HomeDir::FreeDesktop;
@@ -389,7 +389,7 @@ File::Trash::FreeDesktop - Trash files
 
 =head1 VERSION
 
-This document describes version 0.205 of File::Trash::FreeDesktop (from Perl distribution File-Trash-FreeDesktop), released on 2023-08-07.
+This document describes version 0.206 of File::Trash::FreeDesktop (from Perl distribution File-Trash-FreeDesktop), released on 2023-11-21.
 
 =head1 SYNOPSIS
 
